/**
 * 用户管理控制器
 *
 * @author CaiAoLin
 * @date 2017/6/7
 * @version
 */
import BaseController from "../../common/base/base_controller";
import UserModel from "../models/user_model";
import Config from "../../../config/config";

class UserController extends BaseController {

    /**
     * 最近注册列表(最近登录前台用户列表)
     *
     * @param {object} request
     * @param {object} response
     * @return {void}
     */
    async lastRegister(request, response) {
        let userModel = new UserModel();
        let total = 0;
        let pageData = {};
        let userList = [];
        try {
            // 获取用户总数
            total = await userModel.count();

            // 分页数据
            let page = request.query.page === undefined ? 1 : request.query.page;
            pageData = {
                current: page,
                total: parseInt(total / Config.pageSize),
                queryData: response.locals.urlQuery
            };

            // 获取用户列表
            userList = await userModel.getList(null, page);
        } catch (error) {
            console.log(error);
        }

        // 渲染数据
        let renderData = {
            userList: userList,
            pages: pageData,
            total: total,
            model: userModel,
            layout: 'users/views/layout/layout'
        };
        response.render('users/views/user/index', renderData);
    }

}

export default UserController;
